Merge branch 'master' into next
[paraslash.git] / client.h
index 06eeda387932765321c92093ee451aa590b25ae0..5fc336827f4ba187d7b6171a4daeb057806d865d 100644 (file)
--- a/client.h
+++ b/client.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 1997-2009 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -38,11 +38,11 @@ enum {
 /**
  * data specific to a client task
  */
-struct private_client_data {
+struct client_task {
        /** the state of the connection */
        int status;
-       /** the file descriptor */
-       int fd;
+       /** The file descriptor and the rc4 keys. */
+       struct rc4_context rc4c;
        /** the configuration (including the command) */
        struct client_args_info conf;
        /** the config file for client options */
@@ -51,33 +51,24 @@ struct private_client_data {
        char *key_file;
        /** paraslash user name */
        char *user;
-       /** session key for receiving data */
-       RC4_KEY rc4_recv_key;
-       /** session key for sending data */
-       RC4_KEY rc4_send_key;
        /** the client task structure */
        struct task task;
-       /** non-zero if task is unregistered */
-       int eof;
        /** the buffer used for handshake and receiving */
-       char buf[CLIENT_BUFSIZE];
+       char *buf;
        /** number of bytes loaded in \p buf */
        size_t loaded;
        /** non-zero if the pre_select hook added \p fd to the read fd set */
        int check_r;
        /** non-zero if the pre_select hook added \p fd to the write fd set */
        int check_w;
-       /** the decrypted challenge */
-       long unsigned challenge_nr;
        /** pointer to the data to be sent to para_server */
        char *inbuf;
        /** number of bytes loaded in \p inbuf */
        size_t *in_loaded;
-       /** non-zero if input task encountered an eof or an errro condition */
-       int *in_eof;
+       /** Non-zero if input task encountered an eof or an error condition. */
+       int *in_error;
 };
 
-void client_close(struct private_client_data *pcd);
-int client_open(int argc, char *argv[], struct private_client_data **pcd_ptr);
-void client_pre_select(struct sched *s, struct task *t);
-void client_post_select(struct sched *s, struct task *t);
+void client_close(struct client_task *ct);
+int client_open(int argc, char *argv[], struct client_task **ct,
+               int *loglevel);